# Table of Contents

- [inbound-processors](<./inbound-processors.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Inbound Processors](<./Inbound-Processors.md>)
  - [Overview](<./Inbound-Processors/Overview.md>)
  - [Types of Inbound Data Processors](<./Inbound-Processors/Types-of-Inbound-Data-Processors.md>)
  - [Execution of the Started iAPI Runs](<./Inbound-Processors/Execution-of-the-Started-iAPI-Runs.md>)
  - [General Structure](<./Inbound-Processors/General-Structure.md>)
  - [Inbound Fact Sheet](<./Inbound-Processors/Inbound-Fact-Sheet.md>)
  - [Lifecycle Management](<./Inbound-Processors/Lifecycle-Management.md>)
  - [Location Management](<./Inbound-Processors/Location-Management.md>)
  - [Inbound Subscription](<./Inbound-Processors/Inbound-Subscription.md>)
  - [Inbound Relation](<./Inbound-Processors/Inbound-Relation.md>)
  - [Inbound Relations Constraints](<./Inbound-Processors/Inbound-Relations-Constraints.md>)
  - [Inbound Metrics](<./Inbound-Processors/Inbound-Metrics.md>)
  - [Inbound Document](<./Inbound-Processors/Inbound-Document.md>)
  - [Inbound Tag](<./Inbound-Processors/Inbound-Tag.md>)
  - [Write to LDIF](<./Inbound-Processors/Write-to-LDIF.md>)
  - [Inbound Impact](<./Inbound-Processors/Inbound-Impact.md>)
  - [Inbound To-dos](<./Inbound-Processors/Inbound-To-dos.md>)
  - [Was this page helpful?](<./Inbound-Processors/Was-this-page-helpful.md>)
